@@ -19,13 +19,18 @@ class DumpsysActivities(AndroidQFModule):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
         self.results = results if results else {}
 
@@ -56,7 +61,9 @@ class DumpsysActivities(AndroidQFModule):
                 if not in_package:
                     continue
 
-                if line.strip().startswith("------------------------------------------------------------------------------"):  # pylint: disable=line-too-long
+                if line.strip().startswith(
+                    "------------------------------------------------------------------------------"
+                ):  # pylint: disable=line-too-long
                     break
 
                 lines.append(line.rstrip())
