@@ -19,18 +19,23 @@ class Settings(AndroidQFModule):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
         self.results = {}
 
     def run(self) -> None:
         for setting_file in self._get_files_by_pattern("*/settings_*.txt"):
-            namespace = setting_file[setting_file.rfind("_")+1:-4]
+            namespace = setting_file[setting_file.rfind("_") + 1 : -4]
 
             self.results[namespace] = {}
 
@@ -48,11 +53,15 @@ class Settings(AndroidQFModule):
                         continue
 
                     for danger in ANDROID_DANGEROUS_SETTINGS:
-                        if (danger["key"] == key
-                                and danger["safe_value"] != value):
-                            self.log.warning("Found suspicious setting \"%s = %s\" (%s)",
-                                             key, value, danger["description"])
+                        if danger["key"] == key and danger["safe_value"] != value:
+                            self.log.warning(
+                                'Found suspicious setting "%s = %s" (%s)',
+                                key,
+                                value,
+                                danger["description"],
+                            )
                             break
 
-        self.log.info("Identified %d settings",
-                      sum([len(val) for val in self.results.values()]))
+        self.log.info(
+            "Identified %d settings", sum([len(val) for val in self.results.values()])
+        )
