@@ -26,13 +26,18 @@ class Manifest(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def _get_key(self, dictionary, key):
         """Unserialized plist objects can have keys which are str or byte types
@@ -42,8 +47,7 @@ class Manifest(IOSExtraction):
         :param key:
 
         """
-        return (dictionary.get(key.encode("utf-8"), None)
-                or dictionary.get(key, None))
+        return dictionary.get(key.encode("utf-8"), None) or dictionary.get(key, None)
 
     @staticmethod
     def _convert_timestamp(timestamp_or_unix_time_int):
@@ -62,20 +66,23 @@ class Manifest(IOSExtraction):
         if "modified" not in record or "status_changed" not in record:
             return records
 
-        for timestamp in set([record["created"], record["modified"],
-                             record["status_changed"]]):
+        for timestamp in set(
+            [record["created"], record["modified"], record["status_changed"]]
+        ):
             macb = ""
             macb += "M" if timestamp == record["modified"] else "-"
             macb += "-"
             macb += "C" if timestamp == record["status_changed"] else "-"
             macb += "B" if timestamp == record["created"] else "-"
 
-            records.append({
-                "timestamp": timestamp,
-                "module": self.__class__.__name__,
-                "event": macb,
-                "data": f"{record['relative_path']} - {record['domain']}"
-            })
+            records.append(
+                {
+                    "timestamp": timestamp,
+                    "module": self.__class__.__name__,
+                    "event": macb,
+                    "data": f"{record['relative_path']} - {record['domain']}",
+                }
+            )
 
         return records
 
@@ -85,10 +92,15 @@ class Manifest(IOSExtraction):
                 continue
 
             if result["domain"]:
-                if (os.path.basename(result["relative_path"]) == "com.apple.CrashReporter.plist"
-                        and result["domain"] == "RootDomain"):
-                    self.log.warning("Found a potentially suspicious "
-                                     "\"com.apple.CrashReporter.plist\" file created in RootDomain")
+                if (
+                    os.path.basename(result["relative_path"])
+                    == "com.apple.CrashReporter.plist"
+                    and result["domain"] == "RootDomain"
+                ):
+                    self.log.warning(
+                        "Found a potentially suspicious "
+                        '"com.apple.CrashReporter.plist" file created in RootDomain'
+                    )
                     self.detected.append(result)
                     continue
 
@@ -109,8 +121,12 @@ class Manifest(IOSExtraction):
 
                 ioc = self.indicators.check_domain(part)
                 if ioc:
-                    self.log.warning("Found mention of domain \"%s\" in a backup file with "
-                                     "path: %s", ioc["value"], rel_path)
+                    self.log.warning(
+                        'Found mention of domain "%s" in a backup file with '
+                        "path: %s",
+                        ioc["value"],
+                        rel_path,
+                    )
                     result["matched_indicator"] = ioc
                     self.detected.append(result)
 
@@ -119,8 +135,7 @@ class Manifest(IOSExtraction):
         if not os.path.isfile(manifest_db_path):
             raise DatabaseNotFoundError("unable to find backup's Manifest.db")
 
-        self.log.info("Found Manifest.db database at path: %s",
-                      manifest_db_path)
+        self.log.info("Found Manifest.db database at path: %s", manifest_db_path)
 
         conn = sqlite3.connect(manifest_db_path)
         cur = conn.cursor()
@@ -148,27 +163,33 @@ class Manifest(IOSExtraction):
 
                     birth = self._get_key(file_metadata, "Birth")
                     last_modified = self._get_key(file_metadata, "LastModified")
-                    last_status_change = self._get_key(file_metadata,
-                                                       "LastStatusChange")
+                    last_status_change = self._get_key(
+                        file_metadata, "LastStatusChange"
+                    )
 
-                    cleaned_metadata.update({
-                        "created": self._convert_timestamp(birth),
-                        "modified": self._convert_timestamp(last_modified),
-                        "status_changed": self._convert_timestamp(last_status_change),
-                        "mode": oct(self._get_key(file_metadata, "Mode")),
-                        "owner": self._get_key(file_metadata, "UserID"),
-                        "size": self._get_key(file_metadata, "Size"),
-                    })
+                    cleaned_metadata.update(
+                        {
+                            "created": self._convert_timestamp(birth),
+                            "modified": self._convert_timestamp(last_modified),
+                            "status_changed": self._convert_timestamp(
+                                last_status_change
+                            ),
+                            "mode": oct(self._get_key(file_metadata, "Mode")),
+                            "owner": self._get_key(file_metadata, "UserID"),
+                            "size": self._get_key(file_metadata, "Size"),
+                        }
+                    )
                 except Exception:
-                    self.log.exception("Error reading manifest file metadata for file with ID %s "
-                                       "and relative path %s",
-                                       file_data["fileID"],
-                                       file_data["relativePath"])
+                    self.log.exception(
+                        "Error reading manifest file metadata for file with ID %s "
+                        "and relative path %s",
+                        file_data["fileID"],
+                        file_data["relativePath"],
+                    )
 
             self.results.append(cleaned_metadata)
 
         cur.close()
         conn.close()
 
-        self.log.info("Extracted a total of %d file metadata items",
-                      len(self.results))
+        self.log.info("Extracted a total of %d file metadata items", len(self.results))
