@@ -25,13 +25,18 @@ class SafariFavicon(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def serialize(self, record: dict) -> Union[dict, list]:
         return {
@@ -39,7 +44,7 @@ class SafariFavicon(IOSExtraction):
             "module": self.__class__.__name__,
             "event": "safari_favicon",
             "data": f"Safari favicon from {record['url']} with icon URL "
-                    f"{record['icon_url']} ({record['type']})",
+            f"{record['icon_url']} ({record['type']})",
         }
 
     def check_indicators(self) -> None:
@@ -60,7 +65,8 @@ class SafariFavicon(IOSExtraction):
 
         # Fetch valid icon cache.
         cur = conn.cursor()
-        cur.execute("""
+        cur.execute(
+            """
             SELECT
                 page_url.url,
                 icon_info.url,
@@ -68,47 +74,52 @@ class SafariFavicon(IOSExtraction):
             FROM page_url
             JOIN icon_info ON page_url.uuid = icon_info.uuid
             ORDER BY icon_info.timestamp;
-        """)
+        """
+        )
 
         for row in cur:
-            self.results.append({
-                "url": row[0],
-                "icon_url": row[1],
-                "timestamp": row[2],
-                "isodate": convert_mactime_to_iso(row[2]),
-                "type": "valid",
-                "safari_favicon_db_path": file_path,
-            })
+            self.results.append(
+                {
+                    "url": row[0],
+                    "icon_url": row[1],
+                    "timestamp": row[2],
+                    "isodate": convert_mactime_to_iso(row[2]),
+                    "type": "valid",
+                    "safari_favicon_db_path": file_path,
+                }
+            )
 
         # Fetch icons from the rejected icons table.
-        cur.execute("""
+        cur.execute(
+            """
             SELECT
                 page_url,
                 icon_url,
                 timestamp
             FROM rejected_resources ORDER BY timestamp;
-        """)
+        """
+        )
 
         for row in cur:
-            self.results.append({
-                "url": row[0],
-                "icon_url": row[1],
-                "timestamp": row[2],
-                "isodate": convert_mactime_to_iso(row[2]),
-                "type": "rejected",
-                "safari_favicon_db_path": file_path,
-            })
+            self.results.append(
+                {
+                    "url": row[0],
+                    "icon_url": row[1],
+                    "timestamp": row[2],
+                    "isodate": convert_mactime_to_iso(row[2]),
+                    "type": "rejected",
+                    "safari_favicon_db_path": file_path,
+                }
+            )
 
         cur.close()
         conn.close()
 
     def run(self) -> None:
         for file_path in self._get_fs_files_from_patterns(SAFARI_FAVICON_ROOT_PATHS):
-            self.log.info("Found Safari favicon cache database at path: %s",
-                          file_path)
+            self.log.info("Found Safari favicon cache database at path: %s", file_path)
             self._process_favicon_db(file_path)
 
-        self.log.info("Extracted a total of %d favicon records",
-                      len(self.results))
+        self.log.info("Extracted a total of %d favicon records", len(self.results))
 
         self.results = sorted(self.results, key=lambda x: x["isodate"])
