@@ -23,13 +23,18 @@ class ShutdownLog(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def serialize(self, record: dict) -> Union[dict, list]:
         return {
@@ -37,7 +42,7 @@ class ShutdownLog(IOSExtraction):
             "module": self.__class__.__name__,
             "event": "shutdown",
             "data": f"Client {record['client']} with PID {record['pid']} "
-                     "was running when the device was shut down",
+            "was running when the device was shut down",
         }
 
     def check_indicators(self) -> None:
@@ -54,8 +59,11 @@ class ShutdownLog(IOSExtraction):
             for ioc in self.indicators.get_iocs("processes"):
                 parts = result["client"].split("/")
                 if ioc in parts:
-                    self.log.warning("Found mention of a known malicious process \"%s\" in "
-                                     "shutdown.log", ioc)
+                    self.log.warning(
+                        'Found mention of a known malicious process "%s" in '
+                        "shutdown.log",
+                        ioc,
+                    )
                     result["matched_indicator"] = ioc
                     self.detected.append(result)
                     continue
@@ -66,28 +74,32 @@ class ShutdownLog(IOSExtraction):
             line = line.strip()
 
             if line.startswith("remaining client pid:"):
-                current_processes.append({
-                    "pid": line[line.find("pid: ")+5:line.find(" (")],
-                    "client": line[line.find("(")+1:line.find(")")],
-                })
+                current_processes.append(
+                    {
+                        "pid": line[line.find("pid: ") + 5 : line.find(" (")],
+                        "client": line[line.find("(") + 1 : line.find(")")],
+                    }
+                )
             elif line.startswith("SIGTERM: "):
                 try:
-                    mac_timestamp = int(line[line.find("[")+1:line.find("]")])
+                    mac_timestamp = int(line[line.find("[") + 1 : line.find("]")])
                 except ValueError:
                     try:
                         start = line.find(" @") + 2
-                        mac_timestamp = int(line[start:start+10])
+                        mac_timestamp = int(line[start : start + 10])
                     except Exception:
                         mac_timestamp = 0
 
                 isodate = convert_mactime_to_iso(mac_timestamp, from_2001=False)
 
                 for current_process in current_processes:
-                    self.results.append({
-                        "isodate": isodate,
-                        "pid": current_process["pid"],
-                        "client": current_process["client"],
-                    })
+                    self.results.append(
+                        {
+                            "isodate": isodate,
+                            "pid": current_process["pid"],
+                            "client": current_process["client"],
+                        }
+                    )
 
                 current_processes = []
 
