@@ -25,13 +25,18 @@ class IOSVersionHistory(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def serialize(self, record: dict) -> Union[dict, list]:
         return {
@@ -46,12 +51,15 @@ class IOSVersionHistory(IOSExtraction):
             with open(found_path, "r", encoding="utf-8") as analytics_log:
                 log_line = json.loads(analytics_log.readline().strip())
 
-                timestamp = datetime.datetime.strptime(log_line["timestamp"],
-                                                       "%Y-%m-%d %H:%M:%S.%f %z")
+                timestamp = datetime.datetime.strptime(
+                    log_line["timestamp"], "%Y-%m-%d %H:%M:%S.%f %z"
+                )
                 timestamp_utc = timestamp.astimezone(datetime.timezone.utc)
-                self.results.append({
-                    "isodate": convert_datetime_to_iso(timestamp_utc),
-                    "os_version": log_line["os_version"],
-                })
+                self.results.append(
+                    {
+                        "isodate": convert_datetime_to_iso(timestamp_utc),
+                        "os_version": log_line["os_version"],
+                    }
+                )
 
         self.results = sorted(self.results, key=lambda entry: entry["isodate"])
