@@ -25,29 +25,41 @@ class Contacts(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def run(self) -> None:
-        self._find_ios_database(backup_ids=CONTACTS_BACKUP_IDS,
-                                root_paths=CONTACTS_ROOT_PATHS)
+        self._find_ios_database(
+            backup_ids=CONTACTS_BACKUP_IDS, root_paths=CONTACTS_ROOT_PATHS
+        )
         self.log.info("Found Contacts database at path: %s", self.file_path)
 
         conn = sqlite3.connect(self.file_path)
         cur = conn.cursor()
-        cur.execute("""
-            SELECT
-                multi.value, person.first, person.middle, person.last,
-                person.organization
-            FROM ABPerson person, ABMultiValue multi
-            WHERE person.rowid = multi.record_id and multi.value not null
-            ORDER by person.rowid ASC;
-        """)
+        try:
+            cur.execute(
+                """
+                SELECT
+                    multi.value, person.first, person.middle, person.last,
+                    person.organization
+                FROM ABPerson person, ABMultiValue multi
+                WHERE person.rowid = multi.record_id and multi.value not null
+                ORDER by person.rowid ASC;
+            """
+            )
+        except sqlite3.OperationalError as e:
+            self.log.info("Error while reading the contact table: %s", e)
+            return None
         names = [description[0] for description in cur.description]
 
         for row in cur:
@@ -60,5 +72,6 @@ class Contacts(IOSExtraction):
         cur.close()
         conn.close()
 
-        self.log.info("Extracted a total of %d contacts from the address book",
-                      len(self.results))
+        self.log.info(
+            "Extracted a total of %d contacts from the address book", len(self.results)
+        )
