@@ -27,13 +27,18 @@ class FirefoxFavicon(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def serialize(self, record: dict) -> Union[dict, list]:
         return {
@@ -41,7 +46,7 @@ class FirefoxFavicon(IOSExtraction):
             "module": self.__class__.__name__,
             "event": "firefox_history",
             "data": f"Firefox favicon {record['url']} "
-                    f"when visiting {record['history_url']}",
+            f"when visiting {record['history_url']}",
         }
 
     def check_indicators(self) -> None:
@@ -58,14 +63,15 @@ class FirefoxFavicon(IOSExtraction):
                 self.detected.append(result)
 
     def run(self) -> None:
-        self._find_ios_database(backup_ids=FIREFOX_HISTORY_BACKUP_IDS,
-                                root_paths=FIREFOX_HISTORY_ROOT_PATHS)
-        self.log.info("Found Firefox favicon database at path: %s",
-                      self.file_path)
+        self._find_ios_database(
+            backup_ids=FIREFOX_HISTORY_BACKUP_IDS, root_paths=FIREFOX_HISTORY_ROOT_PATHS
+        )
+        self.log.info("Found Firefox favicon database at path: %s", self.file_path)
 
         conn = sqlite3.connect(self.file_path)
         cur = conn.cursor()
-        cur.execute("""
+        cur.execute(
+            """
             SELECT
                 favicons.id,
                 favicons.url,
@@ -78,22 +84,24 @@ class FirefoxFavicon(IOSExtraction):
             FROM favicons
             INNER JOIN favicon_sites ON favicon_sites.faviconID = favicons.id
             INNER JOIN history ON favicon_sites.siteID = history.id;
-        """)
+        """
+        )
 
         for item in cur:
-            self.results.append({
-                "id": item[0],
-                "url": item[1],
-                "width": item[2],
-                "height": item[3],
-                "type": item[4],
-                "isodate": convert_unix_to_iso(item[5]),
-                "history_id": item[6],
-                "history_url": item[7]
-            })
+            self.results.append(
+                {
+                    "id": item[0],
+                    "url": item[1],
+                    "width": item[2],
+                    "height": item[3],
+                    "type": item[4],
+                    "isodate": convert_unix_to_iso(item[5]),
+                    "history_id": item[6],
+                    "history_url": item[7],
+                }
+            )
 
         cur.close()
         conn.close()
 
-        self.log.info("Extracted a total of %d history items",
-                      len(self.results))
+        self.log.info("Extracted a total of %d history items", len(self.results))
