@@ -29,13 +29,18 @@ class IDStatusCache(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def serialize(self, record: dict) -> Union[dict, list]:
         return {
@@ -43,7 +48,7 @@ class IDStatusCache(IOSExtraction):
             "module": self.__class__.__name__,
             "event": "lookup",
             "data": f"Lookup of {record['user']} within {record['package']} "
-                    f"(Status {record['idstatus']})"
+            f"(Status {record['idstatus']})",
         }
 
     def check_indicators(self) -> None:
@@ -60,8 +65,10 @@ class IDStatusCache(IOSExtraction):
                     continue
 
             if "\\x00\\x00" in result.get("user", ""):
-                self.log.warning("Found an ID Status Cache entry with suspicious patterns: %s",
-                                 result.get("user"))
+                self.log.warning(
+                    "Found an ID Status Cache entry with suspicious patterns: %s",
+                    result.get("user"),
+                )
                 self.detected.append(result)
 
     def _extract_idstatuscache_entries(self, file_path):
@@ -80,35 +87,36 @@ class IDStatusCache(IOSExtraction):
                 except KeyError:
                     continue
 
-                id_status_cache_entries.append({
-                    "package": app,
-                    "user": entry.replace("\x00", "\\x00"),
-                    "isodate": convert_mactime_to_iso(lookup_date),
-                    "idstatus": id_status,
-                })
+                id_status_cache_entries.append(
+                    {
+                        "package": app,
+                        "user": entry.replace("\x00", "\\x00"),
+                        "isodate": convert_mactime_to_iso(lookup_date),
+                        "idstatus": id_status,
+                    }
+                )
 
-        entry_counter = collections.Counter([entry["user"]
-                                                for entry in
-                                                    id_status_cache_entries])
+        entry_counter = collections.Counter(
+            [entry["user"] for entry in id_status_cache_entries]
+        )
         for entry in id_status_cache_entries:
             # Add total count of occurrences to the status cache entry.
             entry["occurrences"] = entry_counter[entry["user"]]
             self.results.append(entry)
 
     def run(self) -> None:
-
         if self.is_backup:
             self._find_ios_database(backup_ids=IDSTATUSCACHE_BACKUP_IDS)
-            self.log.info("Found IDStatusCache plist at path: %s",
-                          self.file_path)
+            self.log.info("Found IDStatusCache plist at path: %s", self.file_path)
             self._extract_idstatuscache_entries(self.file_path)
         elif self.is_fs_dump:
             for idstatuscache_path in self._get_fs_files_from_patterns(
-                    IDSTATUSCACHE_ROOT_PATHS):
+                IDSTATUSCACHE_ROOT_PATHS
+            ):
                 self.file_path = idstatuscache_path
-                self.log.info("Found IDStatusCache plist at path: %s",
-                              self.file_path)
+                self.log.info("Found IDStatusCache plist at path: %s", self.file_path)
                 self._extract_idstatuscache_entries(self.file_path)
 
-        self.log.info("Extracted a total of %d ID Status Cache entries",
-                      len(self.results))
+        self.log.info(
+            "Extracted a total of %d ID Status Cache entries", len(self.results)
+        )
