@@ -28,13 +28,18 @@ class SMS(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def serialize(self, record: dict) -> Union[dict, list]:
         text = record["text"].replace("\n", "\\n")
@@ -43,7 +48,7 @@ class SMS(IOSExtraction):
             "module": self.__class__.__name__,
             "event": "sms_received",
             "data": f"{record['service']}: {record['guid']} \"{text}\" "
-                    f"from {record['phone_number']} ({record['account']})"
+            f"from {record['phone_number']} ({record['account']})",
         }
 
     def check_indicators(self) -> None:
@@ -61,20 +66,21 @@ class SMS(IOSExtraction):
                 self.detected.append(result)
 
     def run(self) -> None:
-        self._find_ios_database(backup_ids=SMS_BACKUP_IDS,
-                                root_paths=SMS_ROOT_PATHS)
+        self._find_ios_database(backup_ids=SMS_BACKUP_IDS, root_paths=SMS_ROOT_PATHS)
         self.log.info("Found SMS database at path: %s", self.file_path)
 
         try:
             conn = sqlite3.connect(self.file_path)
             cur = conn.cursor()
-            cur.execute("""
+            cur.execute(
+                """
                 SELECT
                     message.*,
                     handle.id as "phone_number"
                 FROM message, handle
                 WHERE handle.rowid = message.handle_id;
-            """)
+            """
+            )
             # Force the query early to catch database issues
             items = list(cur)
         except sqlite3.DatabaseError as exc:
@@ -83,13 +89,15 @@ class SMS(IOSExtraction):
                 self._recover_sqlite_db_if_needed(self.file_path, forced=True)
                 conn = sqlite3.connect(self.file_path)
                 cur = conn.cursor()
-                cur.execute("""
+                cur.execute(
+                    """
                     SELECT
                         message.*,
                         handle.id as "phone_number"
                     FROM message, handle
                     WHERE handle.rowid = message.handle_id;
-                """)
+                """
+                )
                 items = list(cur)
             else:
                 raise exc
@@ -100,9 +108,11 @@ class SMS(IOSExtraction):
             for index, value in enumerate(item):
                 # We base64 escape some of the attributes that could contain
                 # binary data.
-                if (names[index] == "attributedBody"
-                        or names[index] == "payload_data"
-                        or names[index] == "message_summary_info") and value:
+                if (
+                    names[index] == "attributedBody"
+                    or names[index] == "payload_data"
+                    or names[index] == "message_summary_info"
+                ) and value:
                     value = b64encode(value).decode()
 
                 # We store the value of each column under the proper key.
@@ -110,8 +120,9 @@ class SMS(IOSExtraction):
 
             # We convert Mac's ridiculous timestamp format.
             message["isodate"] = convert_mactime_to_iso(message["date"])
-            message["direction"] = ("sent" if message.get("is_from_me", 0) == 1
-                                        else "received")
+            message["direction"] = (
+                "sent" if message.get("is_from_me", 0) == 1 else "received"
+            )
 
             # Sometimes "text" is None instead of empty string.
             if not message.get("text", None):
@@ -119,8 +130,10 @@ class SMS(IOSExtraction):
 
             alert = "ALERT: State-sponsored attackers may be targeting your iPhone"
             if message.get("text", "").startswith(alert):
-                self.log.warning("Apple warning about state-sponsored attack received on the %s",
-                                 message["isodate"])
+                self.log.warning(
+                    "Apple warning about state-sponsored attack received on the %s",
+                    message["isodate"],
+                )
             else:
                 # Extract links from the SMS message.
                 message_links = check_for_links(message.get("text", ""))
@@ -131,5 +144,4 @@ class SMS(IOSExtraction):
         cur.close()
         conn.close()
 
-        self.log.info("Extracted a total of %d SMS messages",
-                      len(self.results))
+        self.log.info("Extracted a total of %d SMS messages", len(self.results))
