@@ -28,13 +28,18 @@ class SMSAttachments(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def serialize(self, record: dict) -> Union[dict, list]:
         return {
@@ -42,21 +47,21 @@ class SMSAttachments(IOSExtraction):
             "module": self.__class__.__name__,
             "event": "sms_attachment",
             "data": f"{record['service']}: Attachment "
-                    f"'{record['transfer_name']}' {record['direction']} "
-                    f"from {record['phone_number']} "
-                    f"with {record['total_bytes']} bytes "
-                    f"(is_sticker: {record['is_sticker']}, "
-                    f"has_user_info: {record['has_user_info']})"
+            f"'{record['transfer_name']}' {record['direction']} "
+            f"from {record['phone_number']} "
+            f"with {record['total_bytes']} bytes "
+            f"(is_sticker: {record['is_sticker']}, "
+            f"has_user_info: {record['has_user_info']})",
         }
 
     def run(self) -> None:
-        self._find_ios_database(backup_ids=SMS_BACKUP_IDS,
-                                root_paths=SMS_ROOT_PATHS)
+        self._find_ios_database(backup_ids=SMS_BACKUP_IDS, root_paths=SMS_ROOT_PATHS)
         self.log.info("Found SMS database at path: %s", self.file_path)
 
         conn = sqlite3.connect(self.file_path)
         cur = conn.cursor()
-        cur.execute("""
+        cur.execute(
+            """
             SELECT
                 attachment.ROWID as "attachment_id",
                 attachment.*,
@@ -68,33 +73,45 @@ class SMSAttachments(IOSExtraction):
             LEFT JOIN message ON
                 message.ROWID = message_attachment_join.message_id
             LEFT JOIN handle ON handle.ROWID = message.handle_id;
-        """)
+        """
+        )
         names = [description[0] for description in cur.description]
 
         for item in cur:
             attachment = {}
             for index, value in enumerate(item):
-                if (names[index] in ["user_info", "sticker_user_info",
-                                     "attribution_info",
-                                     "ck_server_change_token_blob",
-                                     "sr_ck_server_change_token_blob"]) and value:
+                if (
+                    names[index]
+                    in [
+                        "user_info",
+                        "sticker_user_info",
+                        "attribution_info",
+                        "ck_server_change_token_blob",
+                        "sr_ck_server_change_token_blob",
+                    ]
+                ) and value:
                     value = b64encode(value).decode()
                 attachment[names[index]] = value
 
-            attachment["isodate"] = convert_mactime_to_iso(
-                attachment["created_date"])
-            attachment["start_date"] = convert_mactime_to_iso(
-                attachment["start_date"])
-            attachment["direction"] = ("sent" if attachment["is_outgoing"] == 1 else "received")
+            attachment["isodate"] = convert_mactime_to_iso(attachment["created_date"])
+            attachment["start_date"] = convert_mactime_to_iso(attachment["start_date"])
+            attachment["direction"] = (
+                "sent" if attachment["is_outgoing"] == 1 else "received"
+            )
             attachment["has_user_info"] = attachment["user_info"] is not None
             attachment["service"] = attachment["service"] or "Unknown"
             attachment["filename"] = attachment["filename"] or "NULL"
 
-            if (attachment["filename"].startswith("/var/tmp/")
-                    and attachment["filename"].endswith("-1")
-                    and attachment["direction"] == "received"):
-                self.log.warning("Suspicious iMessage attachment %s on %s",
-                                 attachment['filename'], attachment['isodate'])
+            if (
+                attachment["filename"].startswith("/var/tmp/")
+                and attachment["filename"].endswith("-1")
+                and attachment["direction"] == "received"
+            ):
+                self.log.warning(
+                    "Suspicious iMessage attachment %s on %s",
+                    attachment["filename"],
+                    attachment["isodate"],
+                )
                 self.detected.append(attachment)
 
             self.results.append(attachment)
@@ -102,5 +119,4 @@ class SMSAttachments(IOSExtraction):
         cur.close()
         conn.close()
 
-        self.log.info("Extracted a total of %d SMS attachments",
-                      len(self.results))
+        self.log.info("Extracted a total of %d SMS attachments", len(self.results))
