@@ -18,10 +18,7 @@ TCC_ROOT_PATHS = [
     "private/var/mobile/Library/TCC/TCC.db",
 ]
 
-AUTH_VALUE_OLD = {
-    0: "denied",
-    1: "allowed"
-}
+AUTH_VALUE_OLD = {0: "denied", 1: "allowed"}
 AUTH_VALUES = {
     0: "denied",
     1: "unknown",
@@ -52,28 +49,37 @@ class TCC(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
     def serialize(self, record: dict) -> Union[dict, list]:
         if "last_modified" in record:
             if "allowed_value" in record:
-                msg = (f"Access to {record['service']} by {record['client']} "
-                       f"{record['allowed_value']}")
+                msg = (
+                    f"Access to {record['service']} by {record['client']} "
+                    f"{record['allowed_value']}"
+                )
             else:
-                msg = (f"Access to {record['service']} by {record['client']} "
-                       f"{record['auth_value']}")
+                msg = (
+                    f"Access to {record['service']} by {record['client']} "
+                    f"{record['auth_value']}"
+                )
 
             return {
                 "timestamp": record["last_modified"],
                 "module": self.__class__.__name__,
                 "event": "AccessRequest",
-                "data": msg
+                "data": msg,
             }
 
         return {}
@@ -93,31 +99,36 @@ class TCC(IOSExtraction):
         cur = conn.cursor()
         db_version = "v3"
         try:
-            cur.execute("""SELECT
+            cur.execute(
+                """SELECT
                 service, client, client_type, auth_value,
                 auth_reason, last_modified
-            FROM access;""")
+            FROM access;"""
+            )
         except sqlite3.OperationalError:
             # v2 version
             try:
-                cur.execute("""SELECT
+                cur.execute(
+                    """SELECT
                     service, client, client_type, allowed,
                     prompt_count, last_modified
-                    FROM access;""")
+                    FROM access;"""
+                )
                 db_version = "v2"
             except sqlite3.OperationalError:
-                cur.execute("""SELECT
+                cur.execute(
+                    """SELECT
                     service, client, client_type, allowed,
                     prompt_count
-                    FROM access;""")
+                    FROM access;"""
+                )
                 db_version = "v1"
 
         for row in cur:
             service = row[0]
             client = row[1]
             client_type = row[2]
-            client_type_desc = ("bundle_id" if client_type == 0
-                                    else "absolute_path")
+            client_type_desc = "bundle_id" if client_type == 0 else "absolute_path"
             if db_version == "v3":
                 auth_value = row[3]
                 auth_value_desc = AUTH_VALUES.get(auth_value, "")
@@ -126,19 +137,28 @@ class TCC(IOSExtraction):
                 last_modified = convert_unix_to_iso(row[5])
 
                 if service in ["kTCCServiceMicrophone", "kTCCServiceCamera"]:
-                    device = "microphone" if service == "kTCCServiceMicrophone" else "camera"
-                    self.log.info("Found client \"%s\" with access %s to %s on %s by %s",
-                                  client, auth_value_desc, device,
-                                  last_modified, auth_reason_desc)
+                    device = (
+                        "microphone" if service == "kTCCServiceMicrophone" else "camera"
+                    )
+                    self.log.info(
+                        'Found client "%s" with access %s to %s on %s by %s',
+                        client,
+                        auth_value_desc,
+                        device,
+                        last_modified,
+                        auth_reason_desc,
+                    )
 
-                self.results.append({
-                    "service": service,
-                    "client": client,
-                    "client_type": client_type_desc,
-                    "auth_value": auth_value_desc,
-                    "auth_reason_desc": auth_reason_desc,
-                    "last_modified": last_modified,
-                })
+                self.results.append(
+                    {
+                        "service": service,
+                        "client": client,
+                        "client_type": client_type_desc,
+                        "auth_value": auth_value_desc,
+                        "auth_reason_desc": auth_reason_desc,
+                        "last_modified": last_modified,
+                    }
+                )
             else:
                 allowed_value = row[3]
                 allowed_desc = AUTH_VALUE_OLD.get(allowed_value, "")
@@ -151,41 +171,52 @@ class TCC(IOSExtraction):
                         if service == "kTCCServiceMicrophone":
                             device = "microphone"
 
-                        self.log.info("Found client \"%s\" with access %s to %s at %s",
-                                      client, allowed_desc, device,
-                                      last_modified)
+                        self.log.info(
+                            'Found client "%s" with access %s to %s at %s',
+                            client,
+                            allowed_desc,
+                            device,
+                            last_modified,
+                        )
 
-                    self.results.append({
-                        "service": service,
-                        "client": client,
-                        "client_type": client_type_desc,
-                        "allowed_value": allowed_desc,
-                        "prompt_count": prompt_count,
-                        "last_modified": last_modified
-                    })
+                    self.results.append(
+                        {
+                            "service": service,
+                            "client": client,
+                            "client_type": client_type_desc,
+                            "allowed_value": allowed_desc,
+                            "prompt_count": prompt_count,
+                            "last_modified": last_modified,
+                        }
+                    )
                 else:
                     if service in ["kTCCServiceMicrophone", "kTCCServiceCamera"]:
                         device = "camera"
                         if service == "kTCCServiceMicrophone":
                             device = "microphone"
 
-                        self.log.info("Found client \"%s\" with access %s to %s",
-                                      client, allowed_desc, device)
+                        self.log.info(
+                            'Found client "%s" with access %s to %s',
+                            client,
+                            allowed_desc,
+                            device,
+                        )
 
-                    self.results.append({
-                        "service": service,
-                        "client": client,
-                        "client_type": client_type_desc,
-                        "allowed_value": allowed_desc,
-                        "prompt_count": prompt_count
-                    })
+                    self.results.append(
+                        {
+                            "service": service,
+                            "client": client,
+                            "client_type": client_type_desc,
+                            "allowed_value": allowed_desc,
+                            "prompt_count": prompt_count,
+                        }
+                    )
 
         cur.close()
         conn.close()
 
     def run(self) -> None:
-        self._find_ios_database(backup_ids=TCC_BACKUP_IDS,
-                                root_paths=TCC_ROOT_PATHS)
+        self._find_ios_database(backup_ids=TCC_BACKUP_IDS, root_paths=TCC_ROOT_PATHS)
         self.log.info("Found TCC database at path: %s", self.file_path)
 
         self.process_db(self.file_path)
