@@ -36,13 +36,18 @@ class WebkitSessionResourceLog(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: Optional[bool] = False,
+        fast_mode: bool = False,
         log: logging.Logger = logging.getLogger(__name__),
-        results: Optional[list] = None
+        results: Optional[list] = None,
     ) -> None:
-        super().__init__(file_path=file_path, target_path=target_path,
-                         results_path=results_path, fast_mode=fast_mode,
-                         log=log, results=results)
+        super().__init__(
+            file_path=file_path,
+            target_path=target_path,
+            results_path=results_path,
+            fast_mode=fast_mode,
+            log=log,
+            results=results,
+        )
 
         self.results = {} if not results else results
 
@@ -68,7 +73,8 @@ class WebkitSessionResourceLog(IOSExtraction):
             for entry in entries:
                 source_domains = self._extract_domains(entry["redirect_source"])
                 destination_domains = self._extract_domains(
-                    entry["redirect_destination"])
+                    entry["redirect_destination"]
+                )
 
                 # TODO: Currently not used.
                 # subframe_origins = self._extract_domains(
@@ -77,9 +83,7 @@ class WebkitSessionResourceLog(IOSExtraction):
                 #    entry["subresource_under_origin"])
 
                 all_origins = set(
-                    [entry["origin"]]
-                    + source_domains
-                    + destination_domains
+                    [entry["origin"]] + source_domains + destination_domains
                 )
 
                 ioc = self.indicators.check_domains(all_origins)
@@ -91,7 +95,7 @@ class WebkitSessionResourceLog(IOSExtraction):
                     if len(source_domains) > 0:
                         redirect_path += "SOURCE: "
                         for idx, item in enumerate(source_domains):
-                            source_domains[idx] = f"\"{item}\""
+                            source_domains[idx] = f'"{item}"'
 
                         redirect_path += ", ".join(source_domains)
                         redirect_path += " -> "
@@ -102,12 +106,14 @@ class WebkitSessionResourceLog(IOSExtraction):
                         redirect_path += " -> "
                         redirect_path += "DESTINATION: "
                         for idx, item in enumerate(destination_domains):
-                            destination_domains[idx] = f"\"{item}\""
+                            destination_domains[idx] = f'"{item}"'
 
                         redirect_path += ", ".join(destination_domains)
 
-                    self.log.warning("Found HTTP redirect between suspicious domains: %s",
-                                     redirect_path)
+                    self.log.warning(
+                        "Found HTTP redirect between suspicious domains: %s",
+                        redirect_path,
+                    )
 
     def _extract_browsing_stats(self, log_path):
         items = []
@@ -121,39 +127,52 @@ class WebkitSessionResourceLog(IOSExtraction):
         browsing_stats = file_plist["browsingStatistics"]
 
         for item in browsing_stats:
-            items.append({
-                "origin": item.get("PrevalentResourceOrigin", ""),
-                "redirect_source": item.get("topFrameUniqueRedirectsFrom", ""),
-                "redirect_destination": item.get("topFrameUniqueRedirectsTo", ""),
-                "subframe_under_origin": item.get("subframeUnderTopFrameOrigins", ""),
-                "subresource_under_origin": item.get("subresourceUnderTopFrameOrigins", ""),
-                "user_interaction": item.get("hadUserInteraction"),
-                "most_recent_interaction": convert_datetime_to_iso(
-                    item["mostRecentUserInteraction"]),
-                "last_seen": convert_datetime_to_iso(item["lastSeen"]),
-            })
+            items.append(
+                {
+                    "origin": item.get("PrevalentResourceOrigin", ""),
+                    "redirect_source": item.get("topFrameUniqueRedirectsFrom", ""),
+                    "redirect_destination": item.get("topFrameUniqueRedirectsTo", ""),
+                    "subframe_under_origin": item.get(
+                        "subframeUnderTopFrameOrigins", ""
+                    ),
+                    "subresource_under_origin": item.get(
+                        "subresourceUnderTopFrameOrigins", ""
+                    ),
+                    "user_interaction": item.get("hadUserInteraction"),
+                    "most_recent_interaction": convert_datetime_to_iso(
+                        item["mostRecentUserInteraction"]
+                    ),
+                    "last_seen": convert_datetime_to_iso(item["lastSeen"]),
+                }
+            )
 
         return items
 
     def run(self) -> None:
         if self.is_backup:
             for log_file in self._get_backup_files_from_manifest(
-                    relative_path=WEBKIT_SESSION_RESOURCE_LOG_BACKUP_RELPATH):
+                relative_path=WEBKIT_SESSION_RESOURCE_LOG_BACKUP_RELPATH
+            ):
                 log_path = self._get_backup_file_from_id(log_file["file_id"])
 
                 if not log_path:
                     continue
 
-                self.log.info("Found Safari browsing session resource log at path: %s",
-                              log_path)
+                self.log.info(
+                    "Found Safari browsing session resource log at path: %s", log_path
+                )
                 self.results[log_path] = self._extract_browsing_stats(log_path)
         elif self.is_fs_dump:
             for log_path in self._get_fs_files_from_patterns(
-                    WEBKIT_SESSION_RESOURCE_LOG_ROOT_PATHS):
-                self.log.info("Found Safari browsing session resource log at path: %s",
-                              log_path)
+                WEBKIT_SESSION_RESOURCE_LOG_ROOT_PATHS
+            ):
+                self.log.info(
+                    "Found Safari browsing session resource log at path: %s", log_path
+                )
                 key = os.path.relpath(log_path, self.target_path)
                 self.results[key] = self._extract_browsing_stats(log_path)
 
-        self.log.info("Extracted records from %d Safari browsing session resource logs",
-                      len(self.results))
+        self.log.info(
+            "Extracted records from %d Safari browsing session resource logs",
+            len(self.results),
+        )
